@@ -28,7 +28,7 @@ class SelectUncenteredTransforms(pyblish.api.Action):
             return False
 
         for instance in context:
-            if not instance.data['publish'] or instance.data['_has_succeeded']:
+            if not instance.data['publish'] or not instance.data['_has_failed']:
                 continue
 
             node = instance.data.get('node', None)
@@ -57,10 +57,13 @@ class CenterPivot(pyblish.api.Action):
             if not instance.data['publish']:
                 continue
 
-            node = instance.data.get('node', None)
-            assert node and tp.Dcc.object_exists(node), 'No valid node found in current instance: {}'.format(instance)
+            uncentered_pivots = instance.data.get('uncentered_pivots', None)
+            assert uncentered_pivots, 'No uncentered pivots found in instance: {}'.format(instance)
 
-            maya.cmds.move(0, 0, 0, '{}.scalePivot'.format(node), '.rotatePivot'.format(node), absolute=True)
+            for node in uncentered_pivots:
+                maya.cmds.move(0, 0, 0, '{}.scalePivot'.format(node), '{}.rotatePivot'.format(node), absolute=True)
+            for node in uncentered_pivots:
+                maya.cmds.xform(node, pivots=[0, 0, 0])
 
         return True
 
@@ -68,6 +71,7 @@ class CenterPivot(pyblish.api.Action):
 class ValidateUncenteredPivots(pyblish.api.InstancePlugin):
     """
     Checks if a geometry node has uncentered pivots (pivots that are not centered to (0, 0,, 0) of the world
+    Also to be valid, the geometry and all its parent MUST have their pivots centered to (0, 0, 0) of the world
     """
 
     label = 'Transform - Uncentered Pivots'
@@ -92,6 +96,11 @@ class ValidateUncenteredPivots(pyblish.api.InstancePlugin):
             if maya.cmds.xform(node, query=True, worldSpace=True, rp=True) != [0, 0, 0]:
                 uncentered_pivots.append(node)
 
+        all_parents = tp.Dcc.list_node_parents(node)
+        for parent_node in all_parents:
+            if maya.cmds.xform(parent_node, query=True, worldSpace=True, rp=True) != [0, 0, 0]:
+                uncentered_pivots.append(parent_node)
+
         if uncentered_pivots:
             instance.data['uncentered_pivots'] = uncentered_pivots
 
